@@ -23,8 +23,8 @@
 #include "../CActionSound.h"
 #include "../CActionParameters.h"
 
-CMonoizeAction::CMonoizeAction(const CActionSound &actionSound,const vector<float> _gains,const MonoizeMethods _method) :
-	AAction(actionSound),
+CMonoizeAction::CMonoizeAction(const AActionFactory *factory,const CActionSound *actionSound,const vector<float> _gains,const MonoizeMethods _method) :
+	AAction(factory,actionSound),
 
 	gains(_gains),
 	method(_method),
@@ -41,17 +41,17 @@ CMonoizeAction::~CMonoizeAction()
 		sound->removeTempAudioPools(tempAudioPoolKey);
 }
 
-bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForUndo)
+bool CMonoizeAction::doActionSizeSafe(CActionSound *actionSound,bool prepareForUndo)
 {
 	if(method==mmRemoveAllButOneChannel)
 	{
 		// backup channel 0 into a temp pool
 		if(prepareForUndo)
 		{
-			CActionSound actionSound1(actionSound);
+			CActionSound actionSound1(*actionSound);
 			actionSound1.noChannels();
 			actionSound1.doChannel[0]=true;
-			moveSelectionToTempPools(actionSound1,mmAll,actionSound.sound->getLength());
+			moveSelectionToTempPools(&actionSound1,mmAll,actionSound->sound->getLength());
 		}
 
 		// create accessors for all channels (first is from channel 0 (either backed up or the real think) and rest are from the actionSound
@@ -62,14 +62,14 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 
 			if(gains[0]!=0.0)
 			{
-				srces.push_back(new CRezPoolAccesser(prepareForUndo ? actionSound.sound->getTempAudio(AAction::tempAudioPoolKey,0) : actionSound.sound->getAudio(0)));
+				srces.push_back(new CRezPoolAccesser(prepareForUndo ? actionSound->sound->getTempAudio(AAction::tempAudioPoolKey,0) : actionSound->sound->getAudio(0)));
 				_gains.push_back(gains[0]);
 			}
-			for(unsigned i=1;i<actionSound.sound->getChannelCount();i++)
+			for(unsigned i=1;i<actionSound->sound->getChannelCount();i++)
 			{
 				if(gains[i]!=0.0)
 				{
-					srces.push_back(new CRezPoolAccesser(actionSound.sound->getAudio(i)));
+					srces.push_back(new CRezPoolAccesser(actionSound->sound->getAudio(i)));
 					_gains.push_back(gains[i]);
 				}
 			}
@@ -78,15 +78,15 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 			if(srces.size()<=0)
 			{ // all gains were 0
 				if(!prepareForUndo)
-					actionSound.sound->silenceSound(0,0,actionSound.sound->getLength());
+					actionSound->sound->silenceSound(0,0,actionSound->sound->getLength());
 			}
 			else
 			{
-				CStatusBar statusBar(_("Monoizing"),0,actionSound.sound->getLength(),true);
+				CStatusBar statusBar(_("Monoizing"),0,actionSound->sound->getLength(),true);
 		
-				CRezPoolAccesser dest=actionSound.sound->getAudio(0);
+				CRezPoolAccesser dest=actionSound->sound->getAudio(0);
 		
-				const sample_pos_t length=actionSound.sound->getLength();
+				const sample_pos_t length=actionSound->sound->getLength();
 				const unsigned channelCount=srces.size();
 				for(sample_pos_t t=0;t<length;t++)
 				{
@@ -100,13 +100,13 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 						if(prepareForUndo)
 						{
 							// restore channel 0's data
-							CActionSound actionSound1(actionSound);
+							CActionSound actionSound1(*actionSound);
 							actionSound1.noChannels();
 							actionSound1.doChannel[0]=true;
-							restoreSelectionFromTempPools(actionSound1,0,actionSound.sound->getLength());
+							restoreSelectionFromTempPools(&actionSound1,0,actionSound->sound->getLength());
 						}
 						else
-							actionSound.sound->invalidatePeakData(0u,0,t);
+							actionSound->sound->invalidatePeakData(0u,0,t);
 
 						for(size_t t=0;t<srces.size();t++)
 							delete srces[t];
@@ -129,18 +129,18 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 		// remove all but channel 0 (either backup or really remove)
 		if(prepareForUndo)
 		{
-			CActionSound actionSound2(actionSound);
+			CActionSound actionSound2(*actionSound);
 			actionSound2.allChannels();
 			actionSound2.doChannel[0]=false;
 			
-			origChannelCount=actionSound.sound->getChannelCount();
-			tempAudioPoolKey=actionSound.sound->moveChannelsToTemp(actionSound2.doChannel);
-			sound=actionSound.sound;
+			origChannelCount=actionSound->sound->getChannelCount();
+			tempAudioPoolKey=actionSound->sound->moveChannelsToTemp(actionSound2.doChannel);
+			sound=actionSound->sound;
 		}
 		else
 		{
-			actionSound.sound->invalidatePeakData(0u,0,actionSound.sound->getLength());
-			actionSound.sound->removeChannels(1,actionSound.sound->getChannelCount()-1);
+			actionSound->sound->invalidatePeakData(0u,0,actionSound->sound->getLength());
+			actionSound->sound->removeChannels(1,actionSound->sound->getChannelCount()-1);
 		}
 	}
 	else // if(method==mmMakeAllChannelsToSame)
@@ -154,9 +154,9 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 		// backup all channels into a temp pool
 		if(prepareForUndo)
 		{
-			CActionSound actionSound1(actionSound);
+			CActionSound actionSound1(*actionSound);
 			actionSound1.allChannels();
-			moveSelectionToTempPools(actionSound1,mmAll,actionSound.sound->getLength());
+			moveSelectionToTempPools(&actionSound1,mmAll,actionSound->sound->getLength());
 		}
 
 		// create accessors for all channels (either to the temp pools or the real thing)
@@ -165,11 +165,11 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 		{
 			vector<float> _gains;
 
-			for(unsigned i=0;i<actionSound.sound->getChannelCount();i++)
+			for(unsigned i=0;i<actionSound->sound->getChannelCount();i++)
 			{
 				if(gains[i]!=0.0)
 				{
-					srces.push_back(new CRezPoolAccesser(prepareForUndo ? actionSound.sound->getTempAudio(AAction::tempAudioPoolKey,i) : actionSound.sound->getAudio(i)));
+					srces.push_back(new CRezPoolAccesser(prepareForUndo ? actionSound->sound->getTempAudio(AAction::tempAudioPoolKey,i) : actionSound->sound->getAudio(i)));
 					_gains.push_back(gains[i]);
 				}
 			}
@@ -178,21 +178,21 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 			if(srces.size()<=0)
 			{ // all gains were 0
 				if(prepareForUndo)
-					actionSound.sound->silenceSound(0,0,actionSound.sound->getLength());
+					actionSound->sound->silenceSound(0,0,actionSound->sound->getLength());
 				else
 				{
-					for(unsigned i=0;i<actionSound.sound->getChannelCount();i++)
-						actionSound.sound->silenceSound(i,0,actionSound.sound->getLength());
+					for(unsigned i=0;i<actionSound->sound->getChannelCount();i++)
+						actionSound->sound->silenceSound(i,0,actionSound->sound->getLength());
 				}
 			
 			}
 			else
 			{
-				CStatusBar statusBar(_("Monoizing"),0,actionSound.sound->getLength(),true);
+				CStatusBar statusBar(_("Monoizing"),0,actionSound->sound->getLength(),true);
 		
-				CRezPoolAccesser dest=actionSound.sound->getAudio(0);
+				CRezPoolAccesser dest=actionSound->sound->getAudio(0);
 		
-				const sample_pos_t length=actionSound.sound->getLength();
+				const sample_pos_t length=actionSound->sound->getLength();
 				const unsigned srcChannelCount=srces.size();
 				for(sample_pos_t t=0;t<length;t++)
 				{
@@ -206,13 +206,13 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 
 					if(statusBar.update(t))
 					{ // cancelled
-						CActionSound actionSound1(actionSound);
+						CActionSound actionSound1(*actionSound);
 						actionSound1.allChannels();
 
 						if(prepareForUndo)
-							restoreSelectionFromTempPools(actionSound1,0,actionSound.sound->getLength());
+							restoreSelectionFromTempPools(&actionSound1,0,actionSound->sound->getLength());
 						else
-							actionSound.sound->invalidatePeakData(actionSound1.doChannel,0,t);
+							actionSound->sound->invalidatePeakData(actionSound1.doChannel,0,t);
 
 						for(size_t t=0;t<srces.size();t++)
 							delete srces[t];
@@ -222,8 +222,8 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 				}
 
 				// copy channel 0 to all the other channels
-				for(unsigned i=1;i<actionSound.sound->getChannelCount();i++)
-					actionSound.sound->mixSound(i,0,dest,0,actionSound.sound->getSampleRate(),actionSound.sound->getLength(),mmOverwrite,sftNone,true,true);
+				for(unsigned i=1;i<actionSound->sound->getChannelCount();i++)
+					actionSound->sound->mixSound(i,0,dest,0,actionSound->sound->getSampleRate(),actionSound->sound->getLength(),mmOverwrite,sftNone,true,true);
 			}
 			
 			for(size_t t=0;t<srces.size();t++)
@@ -242,36 +242,36 @@ bool CMonoizeAction::doActionSizeSafe(CActionSound &actionSound,bool prepareForU
 	return true;
 }
 
-AAction::CanUndoResults CMonoizeAction::canUndo(const CActionSound &actionSound) const
+AAction::CanUndoResults CMonoizeAction::canUndo(const CActionSound *actionSound) const
 {
 	return curYes;
 }
 
-void CMonoizeAction::undoActionSizeSafe(const CActionSound &actionSound)
+void CMonoizeAction::undoActionSizeSafe(const CActionSound *actionSound)
 {
 	if(method==mmRemoveAllButOneChannel)
 	{
 		// restore removed channels back into place
-		CActionSound actionSound2(actionSound);
+		CActionSound actionSound2(*actionSound);
 			// make actionSound2 exactly how it was when we called moveChannelsToTemp
 		actionSound2.noChannels();
 		for(unsigned t=1;t<origChannelCount;t++)
 			actionSound2.doChannel[t]=true;
-		actionSound.sound->moveChannelsFromTemp(tempAudioPoolKey,actionSound2.doChannel);
+		actionSound->sound->moveChannelsFromTemp(tempAudioPoolKey,actionSound2.doChannel);
 		tempAudioPoolKey=-1;
 	
 		// restore channel 0's data
-		CActionSound actionSound1(actionSound);
+		CActionSound actionSound1(*actionSound);
 		actionSound1.noChannels();
 		actionSound1.doChannel[0]=true;
-		restoreSelectionFromTempPools(actionSound1,0,actionSound.sound->getLength());
+		restoreSelectionFromTempPools(&actionSound1,0,actionSound->sound->getLength());
 	}
 	else // if(method==mmMakeAllChannelsTheSame)
 	{
-		CActionSound actionSound1(actionSound);
+		CActionSound actionSound1(*actionSound);
 		actionSound1.allChannels();
 
-		restoreSelectionFromTempPools(actionSound1,0,actionSound.sound->getLength());
+		restoreSelectionFromTempPools(&actionSound1,0,actionSound->sound->getLength());
 	}
 }
 
@@ -288,22 +288,24 @@ bool CMonoizeAction::doPreactionSetup(CLoadedSound *loadedSound) const
 CMonoizeActionFactory::CMonoizeActionFactory(AActionDialog *channelSelectDialog,AActionDialog *dialog) :
 	AActionFactory(N_("Monoize"),"",channelSelectDialog,dialog,true,false)
 {
+	selectionPositionsAreApplicable=false;
 }
 
 CMonoizeActionFactory::~CMonoizeActionFactory()
 {
 }
 
-CMonoizeAction *CMonoizeActionFactory::manufactureAction(const CActionSound &actionSound,const CActionParameters *actionParameters) const
+CMonoizeAction *CMonoizeActionFactory::manufactureAction(const CActionSound *actionSound,const CActionParameters *actionParameters) const
 {
 	vector<float> gains;
-	for(unsigned t=0;t<actionSound.sound->getChannelCount();t++)
-		gains.push_back(actionParameters->getDoubleParameter(_("Channel ")+istring(t)));
+	for(unsigned t=0;t<actionSound->sound->getChannelCount();t++)
+		gains.push_back(actionParameters->getValue<float>(_("Channel ")+istring(t)));
 
 	return new CMonoizeAction(
+		this,
 		actionSound,
 		gains,
-		(CMonoizeAction::MonoizeMethods)actionParameters->getUnsignedParameter("Method")
+		(CMonoizeAction::MonoizeMethods)actionParameters->getValue<unsigned>("Method")
 	);
 }
 
