@@ -15,6 +15,12 @@
 #elif defined(HAVE_LIBFOX_1_3)
 	#include <fox-1.3/fx.h>
 	#include <fox-1.3/fxkeys.h>
+#elif defined(HAVE_LIBFOX_1_4)
+	#include <fox-1.4/fx.h>
+	#include <fox-1.4/fxkeys.h>
+#elif defined(HAVE_LIBFOX_1_5)
+	#include <fox-1.5/fx.h>
+	#include <fox-1.5/fxkeys.h>
 #else
 	#error no HAVE_LIBFOX defined
 #endif
