@@ -19,6 +19,7 @@
  */
 
 #warning add a read-only feature to TPoolFile and use it in CrezSoundTranslator::onLoadSound
+#warning add ctrl-mousewheel  perform horizontal zoom into the cursor position (seems like something like this already exists)
 
 #include "../../config/common.h"
 #include "fox_compat.h"
@@ -44,11 +45,14 @@ DECLARE_STATIC_CPATH // to declare CPath::dirDelim
 
 #include "CAboutDialog.h"
 
+#include "CKeyBindingsDialog.h"
+
 static void setupWindows(CMainWindow *mainWindow);
-static void setupAccels(CMainWindow *mainWindow);
 
 static void setLocaleFont(FXApp *application);
 
+// QQQ
+void enableAutoRepeat(void *display,bool enable);
 
 // --- FOR TESTING
 static void countWidgets(FXWindow *w);
@@ -64,11 +68,16 @@ int main(int argc,char *argv[])
 	textdomain(REZOUND_PACKAGE);
 #endif
 
+
 	try
 	{
 		FXApp* application=new FXApp("ReZound","NLT");
 		application->init(argc,argv);
 
+		// QQQ
+		if(argc==2 && string(argv[1])=="--fix-auto-repeat")
+			enableAutoRepeat(application->getDisplay(),true);
+
 #ifdef ENABLE_NLS
 		setLocaleFont(application);
 #endif
@@ -123,9 +132,6 @@ int main(int argc,char *argv[])
 		// create all the dialogs 
 		setupWindows(mainWindow);
 
-		// setup an FXAccelTable which allows for keys to invoke actions
-		setupAccels(mainWindow);
-
 		// load any sounds that were from the previous session
 		const vector<string> errors=gSoundFileManager->loadFilesInRegistry();
 		for(size_t t=0;t<errors.size();t++)
@@ -137,6 +143,7 @@ int main(int argc,char *argv[])
 
 		gAboutDialog->showOnStartup();
 		mainWindow->show();
+		fprintf(stderr,"If rezound dies unexpectedly while seeking with the keyboard, auto-repeat may be disabled.. if this happens run 'rezound --fix-auto-repeat'\n"); // QQQ
 		application->run();
 
 		//countWidgets(application->getRootWindow()); printf("wc: %d\n",wc);
@@ -187,6 +194,8 @@ void setupWindows(CMainWindow *mainWindow)
 {
 		gAboutDialog=new CAboutDialog(mainWindow);
 
+		gKeyBindingsDialog=new CKeyBindingsDialog(mainWindow);
+
 		// create the channel select dialog that AActionFactory is given to use often
 		gChannelSelectDialog=new CChannelSelectDialog(mainWindow);
 
@@ -209,42 +218,6 @@ void setupWindows(CMainWindow *mainWindow)
 		mainWindow->createMenus();
 }
 
-void setupAccels(CMainWindow *mainWindow)
-{
-	FXAccelTable *at=mainWindow->getAccelTable();
-
-
-/* these are not necessary since they are hot-keys on the 'Control' menu
-	// play controls
-	at->addAccel(KEY_a ,mainWindow,MKUINT(CMainWindow::ID_PLAY_SELECTION_ONCE,SEL_COMMAND));
-	at->addAccel(KEY_s ,mainWindow,MKUINT(CMainWindow::ID_STOP,SEL_COMMAND));
-
-	// view
-	at->addAccel(KEY_z ,mainWindow,MKUINT(CMainWindow::ID_FIND_SELECTION_START,SEL_COMMAND));
-	at->addAccel(KEY_x ,mainWindow,MKUINT(CMainWindow::ID_FIND_SELECTION_STOP,SEL_COMMAND));
-*/
-
-	// shuttle (is on the 'Control' menu, but I need a key-up event handler as well)
-	at->addAccel(KEY_1 ,mainWindow,MKUINT(CMainWindow::ID_SHUTTLE_BACKWARD,SEL_COMMAND),MKUINT(CMainWindow::ID_SHUTTLE_RETURN,SEL_COMMAND));
-	//on the 'Control' menu:  at->addAccel(KEY_2 ,mainWindow,MKUINT(CMainWindow::ID_SHUTTLE_INCREASE_RATE,SEL_COMMAND));
-	at->addAccel(KEY_3 ,mainWindow,MKUINT(CMainWindow::ID_SHUTTLE_FORWARD,SEL_COMMAND),MKUINT(CMainWindow::ID_SHUTTLE_RETURN,SEL_COMMAND));
-
-
-	// sound switching
-	at->addAccel(MKUINT(KEY_1,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_2,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_3,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_4,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_5,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_6,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_7,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_8,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_9,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_0,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-	at->addAccel(MKUINT(KEY_quoteleft,ALTMASK),mainWindow,MKUINT(CMainWindow::ID_SOUND_LIST_HOTKEY,SEL_COMMAND));
-}
-
-
 #ifdef ENABLE_NLS
 void setLocaleFont(FXApp *application)
 {
@@ -352,3 +325,50 @@ void listFonts()
 #endif
 
 
+
+// --- QQQ ---------------------------------------------
+// QQQ: HACK: My use of these is a hack (first, the parameter is actually "Display *display").. since we can't (or I don't know 
+// how to) distinguish between a real key press and an autogenerated key-release -> key-press event (coming from keyboard repeats) 
+// I just disable auto-repeat while the seek forward or seek backward events are happening.  Unfortunately it disables it for the
+// whole X display.  I was originally very careful to arrange that XAutoRepeatOn() be called in the event of an unexpected termination,
+// but calling it is apparently not enough because it didn't get restored even though I know it was being called
+extern "C" int XAutoRepeatOn(void *display);
+extern "C" int XAutoRepeatOff(void *display);
+static void *gDisplay=NULL;
+
+void enableAutoRepeat(void *display,bool enable)
+{
+	gDisplay=display; // save this for if we die
+	if(enable)
+		XAutoRepeatOn(display); // QQQ
+	else
+		XAutoRepeatOff(display); // QQQ
+}
+
+/*
+#include <signal.h>
+
+extern "C" void enable_autorepeat_sighandler(int sig)
+{
+	printf("new sig handler called\n");
+	if(gDisplay!=NULL)
+	{
+		printf("enabling auto repeat again\n");
+		XAutoRepeatOn(gDisplay);
+	}
+
+	// now do the default action
+	signal(sig,SIG_DFL);
+	raise(sig);
+}
+
+void setupAutoRepeatFixers()
+{
+	for(int t=1;t<32;t++) // handle all signals 
+	{
+		if(t==9 || t==20 || t==17 || t==18) continue; // ignore these
+		signal(t,enable_autorepeat_sighandler);
+	}
+}
+*/
+
